@@ -19,7 +19,6 @@
  ============================================================================
  Name        : Actions.h
  Author      : Joost Kop
- Version     : 0.1
  Description : Contains a list with links from actionNames to
                the actual Classes
  ============================================================================
@@ -30,18 +29,9 @@
 
 #include "Action.h"
 
-#include "Actions/MediaPlayerPause.h"
-#include "Actions/MediaPlayerPlay.h"
+typedef vector<string> StringList;
 
-struct ActionLink {
-	const char *name;
-	Action *(*CreateAction)();
-};
-
-ActionLink AvailableActionList[] = {
-		{MEDIAPLAYERPAUSE_ACTION_NAME, MediaPlayerPause::Factory },
-		{MEDIAPLAYERPLAY_ACTION_NAME, MediaPlayerPlay::Factory },
-		{ NULL, NULL},
-};
+Action *GetAvailableActionByName(string name);
+StringList GetAllAvailableActions(void);
 
 #endif /* ACTIONS_H */
