@@ -19,7 +19,6 @@
  ============================================================================
  Name        : Containers.h
  Author      : Joost Kop
- Version     : 0.1
  Description : Contains a list with links from containerNames to
                the actual Classes
  ============================================================================
@@ -30,16 +29,10 @@
 
 #include "TriggerContainer.h"
 
-#include "TriggerContainers/Headphone.h"
+typedef vector<TriggerContainer*> TriggerContainerList;
+typedef vector<string> StringList;
 
-struct ContainerLink {
-	const char *name;
-	TriggerContainer *(*CreateContainer)();
-};
-
-ContainerLink AvailableContainerList[] = {
-		{HEADPHONE_CONTAINER_NAME, Headphone::Factory },
-		{ NULL, NULL},
-};
+TriggerContainer *GetAvailableContainerByName(string name);
+StringList GetAllAvailableContainers(void);
 
 #endif /* CONTAINERS_H */
