@@ -19,7 +19,6 @@
  ============================================================================
  Name        : Headphone.h
  Author      : Joost Kop
- Version     : 0.1
  Description : headphone trigger container
  ============================================================================
  */
@@ -38,13 +37,11 @@ class Headphone : public TriggerContainer
 {
 private:
 	GIOChannel* HeadphoneChannel;
-	pthread_t Thread;
-	GMainLoop* MonitorLoop;
 
 public:
 	Headphone();
 	~Headphone();
-	static TriggerContainer *Factory(void);
+	static TriggerContainer *instance(void);
 
 	Trigger *pPluginTrigger;
 	Trigger *pPlugoutTrigger;
